/***********************************************************************
 *
 * Copyright (C) 2004 by FS Forth-Systeme GmbH.
 * All rights reserved.
 *
 * $Id: ns9750_lcd.h,v 1.3 2005/09/07 14:24:05 jdietsch Exp $
 * @Author: Markus Pietrek
 * @References: [1] NS9750 Hardware Reference, March 2004, Chap. 12
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 ***********************************************************************/

#ifndef FS_NS9750_LCD_H
#define FS_NS9750_LCD_H

#define	NS_LCD_MODULE_BASE	 	(0xFA800000) /* virtual address */
#define	NS_LCD_MODULE_BASE_PA	 	(0xA0800000) /* physical address */
#define	NS_LCD_MODULE_SIZE	 	(0x00100000)

#define NS_LCD_TIMING_0			(NS_LCD_MODULE_BASE + 0x0000)
#define NS_LCD_TIMING_1			(NS_LCD_MODULE_BASE + 0x0004)
#define NS_LCD_TIMING_2			(NS_LCD_MODULE_BASE + 0x0008)
#define NS_LCD_TIMING_3			(NS_LCD_MODULE_BASE + 0x000C)
#define NS_LCD_UPBASE			(NS_LCD_MODULE_BASE + 0x0010)
#define NS_LCD_LPBASE			(NS_LCD_MODULE_BASE + 0x0014)
#define NS_LCD_INTREN			(NS_LCD_MODULE_BASE + 0x0018)
#define NS_LCD_CONTROL 			(NS_LCD_MODULE_BASE + 0x001C)
#define NS_LCD_STATUS  			(NS_LCD_MODULE_BASE + 0x0020)
#define NS_LCD_INTR			(NS_LCD_MODULE_BASE + 0x0024)
#define NS_LCD_UPCURR  			(NS_LCD_MODULE_BASE + 0x0028)
#define NS_LCD_LPCURR  			(NS_LCD_MODULE_BASE + 0x002C)
#define NS_LCD_PALETTE 			(NS_LCD_MODULE_BASE + 0x0200)

/* register bit fields */

#define NS_LCD_TIMING_0_HBP(x)		(((x)&0xFF) << 24)
#define NS_LCD_TIMING_0_HFP(x)		(((x)&0xFF) << 16)
#define NS_LCD_TIMING_0_HSW(x)		(((x)&0xFF) <<  8)
#define NS_LCD_TIMING_0_PPL(x)		(((x)&0x3F) <<  2)

#define NS_LCD_TIMING_1_VBP(x)		(((x)&0xFF) << 24)
#define NS_LCD_TIMING_1_VFP(x)		(((x)&0xFF) << 16)
#define NS_LCD_TIMING_1_VSW(x)		(((x)&0x3F) << 10)
#define NS_LCD_TIMING_1_LPP(x)		(((x)&0x3FF))

#define NS_LCD_TIMING_2_BCD		(0x04000000)
#define NS_LCD_TIMING_2_CPL(x)		(((x)&0x3FF) << 16)
#define NS_LCD_TIMING_2_IOE		(0x00004000)
#define NS_LCD_TIMING_2_IPC		(0x00002000)
#define NS_LCD_TIMING_2_IHS		(0x00001000)
#define NS_LCD_TIMING_2_IVS		(0x00000800)
#define NS_LCD_TIMING_2_ACB(x)		(((x)&0x1F) << 6)
#define NS_LCD_TIMING_2_PCD(x)		(((x)&0x1F))

#define NS_LCD_TIMING_3_LEE		(0x00010000)
#define NS_LCD_TIMING_3_LED(x)		(((x)&0x7F))

#define NS_LCD_UPBASE_V(x)		(((x)&0x3FFFFFFF)<<2)

#define NS_LCD_PBASE_V(x)		(((x)&0x3FFFFFFF)<<2)

#define NS_LCD_INTREN_MBERR		(0x00000008)
#define NS_LCD_INTREN_VCOMP		(0x00000004)
#define NS_LCD_INTREN_LNBU		(0x00000002)

#define NS_LCD_CONTROL_WATERMARK	(0x00010000)
#define NS_LCD_CONTROL_VCOMP_MA		(0x00003000)
#define NS_LCD_CONTROL_VCOMP_VS		(0x00000000)
#define NS_LCD_CONTROL_VCOMP_BP		(0x00001000)
#define NS_LCD_CONTROL_VCOMP_AV		(0x00002000)
#define NS_LCD_CONTROL_VCOMP_FP		(0x00003000)
#define NS_LCD_CONTROL_PWR		(0x00000800)
#define NS_LCD_CONTROL_BEPO		(0x00000400)
#define NS_LCD_CONTROL_BEBO		(0x00000200)
#define NS_LCD_CONTROL_BGR		(0x00000100)
#define NS_LCD_CONTROL_DUAL		(0x00000080)
#define NS_LCD_CONTROL_MONO8		(0x00000040)
#define NS_LCD_CONTROL_TFT		(0x00000020)
#define NS_LCD_CONTROL_BW		(0x00000010)
#define NS_LCD_CONTROL_BPP_MA		(0x0000000E)
#define NS_LCD_CONTROL_BPP_1 		(0x00000000)
#define NS_LCD_CONTROL_BPP_2 		(0x00000002)
#define NS_LCD_CONTROL_BPP_4 		(0x00000004)
#define NS_LCD_CONTROL_BPP_8 		(0x00000006)
#define NS_LCD_CONTROL_BPP_16 		(0x00000008)
#define NS_LCD_CONTROL_BPP_24		(0x0000000A)
#define NS_LCD_CONTROL_EN		(0x00000001)

#define NS_LCD_STATUS_MBERROR		(0x00000010)
#define NS_LCD_STATUS_VCOMP		(0x00000008)
#define NS_LCD_STATUS_LNBU		(0x00000004)

#define NS_LCD_INTR_MBERROR		(0x00000010)
#define NS_LCD_INTR_VCOMP		(0x00000008)
#define NS_LCD_INTR_LNBUINTR		(0x00000004)

#define NS_LCD_UPCURR_V(x)		(((x)&0xFFFFFFFF))

#define NS_LCD_LPCURR_V(x)		(((x)&0xFFFFFFFF))

#endif /* FS_NS9750_LCD_H */
